@@ -30,6 +30,12 @@
 #define STRING_IS_VOID(x) (((x) == NULL) || (*(x) == 0))
 
 
+static GthTemplateCode Filename_Special_Codes[] = {
+	{ GTH_TEMPLATE_CODE_TYPE_ENUMERATOR, N_("Enumerator") },
+	{ GTH_TEMPLATE_CODE_TYPE_DATE, N_("Current date"), 'D', 1 },
+};
+
+
 enum {
 	SORT_TYPE_COLUMN_DATA,
 	SORT_TYPE_COLUMN_NAME
@@ -192,24 +198,23 @@ update_sensitivity (DialogData *data)
 
 
 static void
-entry_help_icon_press_cb (GtkEntry             *entry,
-			  GtkEntryIconPosition  icon_pos,
-			  GdkEvent             *event,
-			  gpointer              user_data)
+edit_template_entry_button_clicked_cb (GtkWidget  *widget,
+				       DialogData *data)
 {
-	DialogData *data = user_data;
-	GtkWidget  *help_box = NULL;
+	GtkWidget *dialog;
 
-	if (GTK_WIDGET (entry) == GET_WIDGET ("template_entry"))
-		help_box = GET_WIDGET ("template_help_table");
-
-	if (help_box == NULL)
-		return;
-
-	if (gtk_widget_get_visible (help_box))
-		gtk_widget_hide (help_box);
-	else
-		gtk_widget_show (help_box);
+	dialog = gth_template_editor_dialog_new (Filename_Special_Codes,
+						 G_N_ELEMENTS (Filename_Special_Codes),
+						 0,
+						 _("Edit Template"),
+						 GTK_WINDOW (data->dialog));
+	gth_template_editor_dialog_set_template (GTH_TEMPLATE_EDITOR_DIALOG (dialog),
+						 gtk_entry_get_text (GTK_ENTRY (GET_WIDGET ("template_entry"))));
+	g_signal_connect (dialog,
+			  "response",
+			  G_CALLBACK (gth_template_editor_dialog_default_response),
+			  GET_WIDGET ("template_entry"));
+	gtk_widget_show (dialog);
 }
 
 
@@ -360,14 +365,14 @@ dlg_image_wall (GthBrowser *browser,
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
 				  data->dialog);
-	g_signal_connect (GET_WIDGET ("template_entry"),
-			  "icon-press",
-			  G_CALLBACK (entry_help_icon_press_cb),
-			  data);
 	g_signal_connect_swapped (GET_WIDGET ("single_index_checkbutton"),
 				  "toggled",
 				  G_CALLBACK (update_sensitivity),
 				  data);
+	g_signal_connect (GET_WIDGET ("edit_template_entry_button"),
+			  "clicked",
+			  G_CALLBACK (edit_template_entry_button_clicked_cb),
+			  data);
 
 	/* Run dialog. */
 
