@@ -38,15 +38,19 @@ extern const char *_RATING_TAG_NAMES[];
 
 gboolean   exiv2_read_metadata_from_file    (GFile             *file,
 					     GFileInfo         *info,
+					     gboolean           update_general_attributes,
 					     GCancellable      *cancellable,
 					     GError           **error);
 gboolean   exiv2_read_metadata_from_buffer  (void              *buffer,
 					     gsize              buffer_size,
 					     GFileInfo         *info,
+					     gboolean           update_general_attributes,
 					     GError           **error);
 GFile *    exiv2_get_sidecar                (GFile             *file);
 gboolean   exiv2_read_sidecar               (GFile             *file,
-					     GFileInfo         *info);
+					     GFileInfo         *info,
+					     gboolean           update_general_attributes);
+void       exiv2_update_general_attributes  (GFileInfo         *info);
 gboolean   exiv2_supports_writes            (const char        *mime_type);
 gboolean   exiv2_write_metadata  	    (GthImageSaveData  *data);
 gboolean   exiv2_write_metadata_to_buffer   (void              **buffer,
