@@ -246,6 +246,13 @@ gth_file_viewer_page_real_focus (GthViewerPage *base)
 }
 
 
+static gboolean
+gth_file_viewer_page_real_has_focus (GthViewerPage *base)
+{
+	return FALSE;
+}
+
+
 static void
 gth_file_viewer_page_real_fullscreen (GthViewerPage *base,
 				      gboolean       active)
@@ -288,6 +295,24 @@ gth_file_viewer_page_real_update_info (GthViewerPage *base,
 }
 
 
+static gboolean
+gth_file_viewer_page_can_open_clipboard (GthViewerPage *base,
+					 GdkAtom       *atoms,
+					 int            n_atoms)
+
+{
+	return FALSE;
+}
+
+
+static void
+gth_file_viewer_page_open_clipboard (GthViewerPage *base,
+				     GtkClipboard *clipboard)
+{
+	// VOID
+}
+
+
 static void
 gth_file_viewer_page_finalize (GObject *obj)
 {
@@ -319,11 +344,14 @@ gth_viewer_page_interface_init (GthViewerPageInterface *iface)
 	iface->can_view = gth_file_viewer_page_real_can_view;
 	iface->view = gth_file_viewer_page_real_view;
 	iface->focus = gth_file_viewer_page_real_focus;
+	iface->has_focus = gth_file_viewer_page_real_has_focus;
 	iface->fullscreen = gth_file_viewer_page_real_fullscreen;
 	iface->show_pointer = gth_file_viewer_page_real_show_pointer;
 	iface->update_sensitivity = gth_file_viewer_page_real_update_sensitivity;
 	iface->can_save = gth_file_viewer_page_real_can_save;
 	iface->update_info = gth_file_viewer_page_real_update_info;
+	iface->can_open_clipboard = gth_file_viewer_page_can_open_clipboard;
+	iface->open_clipboard = gth_file_viewer_page_open_clipboard;
 }
 
 
