@@ -124,18 +124,39 @@ get_screenshot_file (SaveData  *save_data,
 }
 
 
-static void
-screenshot_ready_cb (GdkPixbuf *pixbuf,
-		     gpointer   user_data)
+void
+gth_browser_activate_video_screenshot (GSimpleAction	*action,
+				       GVariant	*parameter,
+				       gpointer	 user_data)
 {
-	SaveData *save_data = user_data;
-	GFile    *file;
-	GError   *error = NULL;
-	GthTask  *task;
+	GthBrowser		*browser = GTH_BROWSER (user_data);
+	GthMediaViewerPage	*page;
+	GstElement		*playbin;
+	SaveData		*save_data;
+	GdkPixbuf		*pixbuf;
+	GFile			*file;
+	GError			*error = NULL;
+	GthTask		*task;
 
+	page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
+	playbin = gth_media_viewer_page_get_playbin (page);
+	if (playbin == NULL)
+		return;
+
+	save_data = g_new0 (SaveData, 1);
+	save_data->browser = gth_media_viewer_page_get_browser (page);
+	save_data->settings = g_settings_new (GTHUMB_GSTREAMER_TOOLS_SCHEMA);
+	save_data->page = page;
+	save_data->playing_before_screenshot = gth_media_viewer_page_is_playing (page);
+
+	if (save_data->playing_before_screenshot)
+		gst_element_set_state (playbin, GST_STATE_PAUSED);
+
+	pixbuf = _gst_playbin_get_current_frame (playbin, &error);
 	if (pixbuf == NULL) {
-		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (save_data->browser), _("Could not take a screenshot"), NULL);
+		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (save_data->browser), _("Could not take a screenshot"), error);
 		save_date_free (save_data);
+		g_clear_error (&error);
 		return;
 	}
 
@@ -165,35 +186,6 @@ screenshot_ready_cb (GdkPixbuf *pixbuf,
 }
 
 
-void
-gth_browser_activate_video_screenshot (GSimpleAction	*action,
-				       GVariant		*parameter,
-				       gpointer		 user_data)
-{
-	GthBrowser		*browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage	*page;
-	GstElement		*playbin;
-	SaveData		*save_data;
-
-	page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
-	playbin = gth_media_viewer_page_get_playbin (page);
-	if (playbin == NULL)
-		return;
-
-	save_data = g_new0 (SaveData, 1);
-	save_data->browser = gth_media_viewer_page_get_browser (page);
-	save_data->settings = g_settings_new (GTHUMB_GSTREAMER_TOOLS_SCHEMA);
-	save_data->page = page;
-	save_data->playing_before_screenshot = gth_media_viewer_page_is_playing (page);
-
-	if (save_data->playing_before_screenshot)
-		gst_element_set_state (playbin, GST_STATE_PAUSED);
-	_gst_playbin_get_current_frame (playbin,
-					screenshot_ready_cb,
-					save_data);
-}
-
-
 void
 gth_browser_activate_toggle_play (GSimpleAction	*action,
 				  GVariant	*parameter,
@@ -252,7 +244,7 @@ gth_browser_activate_video_zoom_fit (GSimpleAction	*action,
 				     gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	g_simple_action_set_state (action, state);
 	gth_media_viewer_page_set_fit_if_larger (page, g_variant_get_boolean (state));
@@ -265,7 +257,7 @@ gth_browser_activate_next_video_frame (GSimpleAction	*action,
 				       gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_next_frame (page);
 }
@@ -277,7 +269,7 @@ gth_browser_activate_skip_forward_smallest (GSimpleAction	*action,
 					    gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, 1);
 }
@@ -289,7 +281,7 @@ gth_browser_activate_skip_forward_smaller (GSimpleAction	*action,
 					   gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, 5);
 }
@@ -301,7 +293,7 @@ gth_browser_activate_skip_forward_small (GSimpleAction	*action,
 					 gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, 10);
 }
@@ -313,7 +305,7 @@ gth_browser_activate_skip_forward_big (GSimpleAction	*action,
 				       gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, 60);
 }
@@ -325,7 +317,7 @@ gth_browser_activate_skip_forward_bigger (GSimpleAction	*action,
 					  gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, 60 * 5);
 }
@@ -337,7 +329,7 @@ gth_browser_activate_skip_back_smallest (GSimpleAction	*action,
 					 gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, -1);
 }
@@ -349,7 +341,7 @@ gth_browser_activate_skip_back_smaller (GSimpleAction	*action,
 					gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, -5);
 }
@@ -361,7 +353,7 @@ gth_browser_activate_skip_back_small (GSimpleAction	*action,
 				      gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, -10);
 }
@@ -373,7 +365,7 @@ gth_browser_activate_skip_back_big (GSimpleAction	*action,
 				    gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, -60);
 }
@@ -385,7 +377,46 @@ gth_browser_activate_skip_back_bigger (GSimpleAction	*action,
 				       gpointer		 user_data)
 {
 	GthBrowser	   *browser = GTH_BROWSER (user_data);
-	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));;
+	GthMediaViewerPage *page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
 
 	gth_media_viewer_page_skip (page, -60 * 5);
 }
+
+
+void
+gth_browser_activate_copy_frame (GSimpleAction	*action,
+				 GVariant		*state,
+				 gpointer		 user_data)
+{
+	GthBrowser		*browser = GTH_BROWSER (user_data);
+	GthMediaViewerPage	*page;
+	GstElement		*playbin;
+	gboolean		 was_playing;
+	GError			*error = NULL;
+	GdkPixbuf		*pixbuf;
+	GtkClipboard		*clipboard;
+
+	page = GTH_MEDIA_VIEWER_PAGE (gth_browser_get_viewer_page (browser));
+	playbin = gth_media_viewer_page_get_playbin (page);
+	if (playbin == NULL)
+		return;
+
+	was_playing = gth_media_viewer_page_is_playing (page);
+	if (was_playing)
+		gst_element_set_state (playbin, GST_STATE_PAUSED);
+
+	pixbuf = _gst_playbin_get_current_frame (playbin, &error);
+	if (pixbuf == NULL) {
+		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (browser), _("Could not take a screenshot"), error);
+		g_clear_error (&error);
+		return;
+	}
+
+	clipboard = gtk_clipboard_get_for_display (gtk_widget_get_display (GTK_WIDGET (browser)), GDK_SELECTION_CLIPBOARD);
+	gtk_clipboard_set_image (clipboard, pixbuf);
+
+	if (was_playing)
+		gst_element_set_state (playbin, GST_STATE_PLAYING);
+
+	g_object_unref (pixbuf);
+}
