@@ -76,6 +76,7 @@ struct _GthMediaViewerPagePrivate {
 	GtkWidget      *screenshot_button;
 	GtkWidget      *fit_button;
 	gboolean        background_painted;
+	guint           file_popup_merge_id;
 };
 
 
@@ -108,6 +109,12 @@ static const GActionEntry actions[] = {
 	{ "skip-back-big", gth_browser_activate_skip_back_big },
 	{ "skip-back-bigger", gth_browser_activate_skip_back_bigger },
 	{ "video-zoom-fit", toggle_action_activated, NULL, "true", gth_browser_activate_video_zoom_fit },
+	{ "copy-frame", gth_browser_activate_copy_frame },
+};
+
+
+static const GthMenuEntry file_popup_entries[] = {
+	{ N_("Copy Image"), "win.copy-frame" },
 };
 
 
@@ -833,6 +840,7 @@ static void
 create_playbin (GthMediaViewerPage *self)
 {
 	GstElement *scaletempo;
+	gboolean    sink_created;
 	GstBus     *bus;
 
 	if (self->priv->playbin != NULL)
@@ -844,18 +852,29 @@ create_playbin (GthMediaViewerPage *self)
 	if (scaletempo != NULL)
 		g_object_set (self->priv->playbin, "audio-filter", scaletempo, NULL);
 
+	sink_created = FALSE;
 	if (g_settings_get_boolean (self->priv->settings, PREF_GSTREAMER_USE_HARDWARE_ACCEL)) {
-		GstElement *glsinkbin;
 		GstElement *gtkglsink;
 
-		glsinkbin = gst_element_factory_make ("glsinkbin", "");
 		gtkglsink = gst_element_factory_make ("gtkglsink", "sink");
-		g_object_set (glsinkbin, "sink", gtkglsink, NULL);
-		g_object_set (self->priv->playbin, "video-sink", glsinkbin, NULL);
+		if (gtkglsink != NULL) {
+			GstElement *glsinkbin;
 
-		g_object_get (gtkglsink, "widget", &self->priv->video_area, NULL);
+			glsinkbin = gst_element_factory_make ("glsinkbin", "");
+			if (glsinkbin != NULL) {
+				g_object_set (glsinkbin,
+					      "enable-last-sample", TRUE,
+					      "sink", gtkglsink,
+					      NULL);
+				g_object_set (self->priv->playbin, "video-sink", glsinkbin, NULL);
+				g_object_get (gtkglsink, "widget", &self->priv->video_area, NULL);
+
+				sink_created = TRUE;
+			}
+		}
 	}
-	else {
+
+	if (! sink_created) {
 		GstElement *gtksink;
 
 		gtksink = gst_element_factory_make ("gtksink", "sink");
@@ -912,6 +931,8 @@ create_playbin (GthMediaViewerPage *self)
 			  "message",
 			  G_CALLBACK (bus_message_cb),
 			  self);
+
+	g_object_unref (bus);
 }
 
 
@@ -1342,6 +1363,11 @@ gth_media_viewer_page_real_deactivate (GthViewerPage *base)
 
 		gst_element_set_state (self->priv->playbin, GST_STATE_NULL);
 		wait_playbin_state_change_to_complete (self);
+		GstBus *bus = gst_element_get_bus (self->priv->playbin);
+		if (bus != NULL) {
+			gst_bus_remove_signal_watch (bus);
+			g_object_unref (bus);
+		}
 		gst_object_unref (GST_OBJECT (self->priv->playbin));
 		self->priv->playbin = NULL;
 		self->priv->video_area = NULL;
@@ -1377,6 +1403,12 @@ gth_media_viewer_page_real_show (GthViewerPage *base)
 {
 	GthMediaViewerPage *self = GTH_MEDIA_VIEWER_PAGE (base);
 
+	if (self->priv->file_popup_merge_id == 0)
+		self->priv->file_popup_merge_id =
+				gth_menu_manager_append_entries (gth_browser_get_menu_manager (self->priv->browser, GTH_BROWSER_MENU_MANAGER_FILE_EDIT_ACTIONS),
+								 file_popup_entries,
+								 G_N_ELEMENTS (file_popup_entries));
+
 	self->priv->visible = TRUE;
 	self->priv->background_painted = FALSE;
 	gth_viewer_page_focus (GTH_VIEWER_PAGE (self));
@@ -1399,6 +1431,9 @@ gth_media_viewer_page_real_hide (GthViewerPage *base)
 
 	self = (GthMediaViewerPage*) base;
 
+	gth_menu_manager_remove_entries (gth_browser_get_menu_manager (self->priv->browser, GTH_BROWSER_MENU_MANAGER_FILE_EDIT_ACTIONS), self->priv->file_popup_merge_id);
+	self->priv->file_popup_merge_id = 0;
+
 	self->priv->visible = FALSE;
 	if ((self->priv->playbin != NULL) && self->priv->playing)
 		gst_element_set_state (self->priv->playbin, GST_STATE_PAUSED);
@@ -1483,6 +1518,22 @@ gth_media_viewer_page_real_focus (GthViewerPage *base)
 }
 
 
+static gboolean
+gth_media_viewer_page_real_has_focus (GthViewerPage *base)
+{
+	GthMediaViewerPage *self = (GthMediaViewerPage*) base;
+	GtkWidget          *widget;
+
+	widget = NULL;
+	if (self->priv->has_video)
+		widget = self->priv->video_area;
+	else if (self->priv->has_audio)
+		widget = self->priv->audio_area;
+
+	return gtk_widget_has_focus (widget);
+}
+
+
 static void
 gth_media_viewer_page_real_fullscreen (GthViewerPage *base,
 				       gboolean       active)
@@ -1523,6 +1574,7 @@ gth_media_viewer_page_real_update_sensitivity (GthViewerPage *base)
 	gtk_widget_set_sensitive (GET_WIDGET ("play_button"), self->priv->has_video || self->priv->has_audio);
 	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "video-screenshot", self->priv->has_video);
 	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "video-zoom-fit", self->priv->has_video);
+	gth_window_enable_action (GTH_WINDOW (self->priv->browser), "copy-frame", self->priv->has_video);
 }
 
 
@@ -1580,6 +1632,24 @@ gth_media_viewer_page_shortcut_context (GthViewerPage *base)
 }
 
 
+static gboolean
+gth_media_viewer_page_can_open_clipboard (GthViewerPage *base,
+					  GdkAtom       *atoms,
+					  int            n_atoms)
+
+{
+	return FALSE;
+}
+
+
+static void
+gth_media_viewer_page_open_clipboard (GthViewerPage *base,
+				      GtkClipboard *clipboard)
+{
+	// VOID
+}
+
+
 static void
 gth_media_viewer_page_finalize (GObject *obj)
 {
@@ -1627,6 +1697,7 @@ gth_viewer_page_interface_init (GthViewerPageInterface *iface)
 	iface->can_view = gth_media_viewer_page_real_can_view;
 	iface->view = gth_media_viewer_page_real_view;
 	iface->focus = gth_media_viewer_page_real_focus;
+	iface->has_focus = gth_media_viewer_page_real_has_focus;
 	iface->fullscreen = gth_media_viewer_page_real_fullscreen;
 	iface->show_pointer = gth_media_viewer_page_real_show_pointer;
 	iface->update_sensitivity = gth_media_viewer_page_real_update_sensitivity;
@@ -1636,6 +1707,8 @@ gth_viewer_page_interface_init (GthViewerPageInterface *iface)
 	iface->revert = gth_media_viewer_page_real_revert;
 	iface->update_info = gth_media_viewer_page_real_update_info;
 	iface->shortcut_context = gth_media_viewer_page_shortcut_context;
+	iface->can_open_clipboard = gth_media_viewer_page_can_open_clipboard;
+	iface->open_clipboard = gth_media_viewer_page_open_clipboard;
 }
 
 
@@ -1670,6 +1743,7 @@ gth_media_viewer_page_init (GthMediaViewerPage *self)
 	self->priv->updated_info = NULL;
 	self->priv->loop = FALSE;
 	self->priv->fit_if_larger = TRUE;
+	self->priv->file_popup_merge_id = 0;
 
 	/* settings notifications */
 
