@@ -31,6 +31,7 @@
 typedef struct {
 	GtkBuilder *builder;
 	GSettings  *settings;
+	GSettings  *browser_settings;
 } BrowserData;
 
 
@@ -39,6 +40,7 @@ browser_data_free (BrowserData *data)
 {
 	g_object_unref (data->builder);
 	g_object_unref (data->settings);
+	g_object_unref (data->browser_settings);
 	g_free (data);
 }
 
@@ -59,6 +61,15 @@ reset_scrollbars_toggled_cb (GtkToggleButton *button,
 }
 
 
+static void
+scroll_event_toggled_cb (GtkToggleButton *button,
+			 BrowserData     *data)
+{
+	g_settings_set_enum (data->browser_settings,
+			     PREF_VIEWER_SCROLL_ACTION,
+			     (GTK_WIDGET (button) == GET_WIDGET ("scroll_event_change_image_radiobutton")) ? GTH_SCROLL_ACTION_CHANGE_FILE : GTH_SCROLL_ACTION_ZOOM);
+}
+
 static void
 zoom_quality_radiobutton_toggled_cb (GtkToggleButton *button,
 				     BrowserData     *data)
@@ -67,6 +78,16 @@ zoom_quality_radiobutton_toggled_cb (GtkToggleButton *button,
 }
 
 
+static void
+transparency_style_changed_cb (GtkComboBox *combo_box,
+			       BrowserData *data)
+{
+	g_settings_set_enum (data->settings,
+			     PREF_IMAGE_VIEWER_TRANSPARENCY_STYLE,
+			     gtk_combo_box_get_active (combo_box));
+}
+
+
 void
 image_viewer__dlg_preferences_construct_cb (GtkWidget  *dialog,
 					    GthBrowser *browser,
@@ -80,11 +101,11 @@ image_viewer__dlg_preferences_construct_cb (GtkWidget  *dialog,
 	data = g_new0 (BrowserData, 1);
 	data->builder = _gtk_builder_new_from_file ("image-viewer-preferences.ui", "image_viewer");
 	data->settings = g_settings_new (GTHUMB_IMAGE_VIEWER_SCHEMA);
+	data->browser_settings = g_settings_new (GTHUMB_BROWSER_SCHEMA);
 
 	notebook = _gtk_builder_get_widget (dialog_builder, "notebook");
 
 	page = _gtk_builder_get_widget (data->builder, "preferences_page");
-	g_object_set_data (G_OBJECT (page), "extension-name", "image_viewer");
 	gtk_widget_show (page);
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("change_zoom_combobox")),
@@ -97,10 +118,26 @@ image_viewer__dlg_preferences_construct_cb (GtkWidget  *dialog,
 	else
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("zoom_quality_high_radiobutton")), TRUE);
 
+	if (g_settings_get_enum (data->browser_settings, PREF_VIEWER_SCROLL_ACTION) == GTH_SCROLL_ACTION_CHANGE_FILE)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("scroll_event_change_image_radiobutton")), TRUE);
+	else
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("scroll_event_zoom_radiobutton")), TRUE);
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("transparency_style_combobox")),
+				  g_settings_get_enum (data->settings, PREF_IMAGE_VIEWER_TRANSPARENCY_STYLE));
+
 	g_signal_connect (GET_WIDGET ("change_zoom_combobox"),
 			  "changed",
 			  G_CALLBACK (zoom_change_changed_cb),
 			  data);
+	g_signal_connect (GET_WIDGET ("scroll_event_change_image_radiobutton"),
+			  "toggled",
+			  G_CALLBACK (scroll_event_toggled_cb),
+			  data);
+	g_signal_connect (GET_WIDGET ("scroll_event_zoom_radiobutton"),
+			  "toggled",
+			  G_CALLBACK (scroll_event_toggled_cb),
+			  data);
 	g_signal_connect (GET_WIDGET ("zoom_quality_low_radiobutton"),
 			  "toggled",
 			  G_CALLBACK (zoom_quality_radiobutton_toggled_cb),
@@ -113,6 +150,10 @@ image_viewer__dlg_preferences_construct_cb (GtkWidget  *dialog,
 			  "toggled",
 			  G_CALLBACK (reset_scrollbars_toggled_cb),
 			  data);
+	g_signal_connect (GET_WIDGET ("transparency_style_combobox"),
+			  "changed",
+			  G_CALLBACK (transparency_style_changed_cb),
+			  data);
 
 	label = gtk_label_new (_("Viewer"));
 	gtk_widget_show (label);
