@@ -26,9 +26,6 @@
 #define GET_WIDGET(x) (_gtk_builder_get_widget (self->priv->builder, (x)))
 
 
-G_DEFINE_TYPE (OAuthAccountChooserDialog, oauth_account_chooser_dialog, GTK_TYPE_DIALOG)
-
-
 enum {
 	ACCOUNT_DATA_COLUMN,
 	ACCOUNT_NAME_COLUMN,
@@ -42,6 +39,12 @@ struct _OAuthAccountChooserDialogPrivate {
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (OAuthAccountChooserDialog,
+			 oauth_account_chooser_dialog,
+			 GTK_TYPE_DIALOG,
+			 G_ADD_PRIVATE (OAuthAccountChooserDialog))
+
+
 static void
 oauth_account_chooser_dialog_finalize (GObject *object)
 {
@@ -60,8 +63,6 @@ oauth_account_chooser_dialog_class_init (OAuthAccountChooserDialogClass *klass)
 {
 	GObjectClass *object_class;
 
-	g_type_class_add_private (klass, sizeof (OAuthAccountChooserDialogPrivate));
-
 	object_class = (GObjectClass*) klass;
 	object_class->finalize = oauth_account_chooser_dialog_finalize;
 }
@@ -111,7 +112,7 @@ oauth_account_chooser_dialog_init (OAuthAccountChooserDialog *self)
 {
 	GtkWidget *content;
 
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, OAUTH_TYPE_ACCOUNT_CHOOSER_DIALOG, OAuthAccountChooserDialogPrivate);
+	self->priv = oauth_account_chooser_dialog_get_instance_private (self);
 	self->priv->builder = _gtk_builder_new_from_file ("oauth-account-chooser.ui", "oauth");
 
 	content = _gtk_builder_get_widget (self->priv->builder, "account_chooser");
