@@ -22,7 +22,6 @@
 #include <config.h>
 #include <gtk/gtk.h>
 #include "dlg-personalize-filters.h"
-#include "gconf-utils.h"
 #include "glib-utils.h"
 #include "gth-filter-editor-dialog.h"
 #include "gth-main.h"
@@ -46,6 +45,7 @@ enum {
 typedef struct {
 	GthBrowser   *browser;
 	GtkBuilder   *builder;
+	GSettings    *settings;
 	GtkWidget    *dialog;
 	GtkWidget    *list_view;
 	GtkWidget    *general_filter_combobox;
@@ -69,6 +69,7 @@ destroy_cb (GtkWidget  *widget,
 
 	_g_string_list_free (data->general_tests);
 	g_object_unref (data->builder);
+	g_object_unref (data->settings);
 	g_free (data);
 }
 
@@ -311,7 +312,8 @@ filter_editor_dialog__response_cb (GtkDialog *dialog,
 
 	filter = gth_filter_editor_dialog_get_filter (GTH_FILTER_EDITOR_DIALOG (dialog), &error);
 	if (filter == NULL) {
-		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (dialog), _("Could not save the filter"), &error);
+		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (dialog), _("Could not save the filter"), error);
+		g_clear_error (&error);
 		return;
 	}
 
@@ -488,7 +490,7 @@ general_filter_changed_cb (GtkComboBox *widget,
 	int         idx;
 
 	idx = gtk_combo_box_get_active (widget);
-	eel_gconf_set_string (PREF_GENERAL_FILTER, g_list_nth (data->general_tests, idx)->data);
+	g_settings_set_string (data->settings, PREF_BROWSER_GENERAL_FILTER, g_list_nth (data->general_tests, idx)->data);
 }
 
 
@@ -509,17 +511,30 @@ dlg_personalize_filters (GthBrowser *browser)
 	data = g_new0 (DialogData, 1);
 	data->browser = browser;
 	data->builder = _gtk_builder_new_from_file ("personalize-filters.ui", NULL);
+	data->settings = g_settings_new (GTHUMB_BROWSER_SCHEMA);
 
 	/* Get the widgets. */
 
-	data->dialog = _gtk_builder_get_widget (data->builder, "personalize_filters_dialog");
+	data->dialog = g_object_new (GTK_TYPE_DIALOG,
+				     "title", _("Filters"),
+				     "transient-for", GTK_WINDOW (browser),
+				     "modal", FALSE,
+				     "destroy-with-parent", FALSE,
+				     "use-header-bar", _gtk_settings_get_dialogs_use_header (),
+				     NULL);
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (data->dialog))),
+			   _gtk_builder_get_widget (data->builder, "dialog_content"));
+	gtk_dialog_add_buttons (GTK_DIALOG (data->dialog),
+				_GTK_LABEL_OK, GTK_RESPONSE_CLOSE,
+				NULL);
+
 	gth_browser_set_dialog (browser, "personalize_filters", data->dialog);
 	g_object_set_data (G_OBJECT (data->dialog), "dialog_data", data);
 
 	/* Set widgets data. */
 
 	tests = gth_main_get_registered_objects_id (GTH_TYPE_TEST);
-	general_filter = eel_gconf_get_string (PREF_GENERAL_FILTER, DEFAULT_GENERAL_FILTER);
+	general_filter = g_settings_get_string (data->settings, PREF_BROWSER_GENERAL_FILTER);
 	active_filter = 0;
 
 	data->general_filter_combobox = gtk_combo_box_text_new ();
@@ -581,7 +596,7 @@ dlg_personalize_filters (GthBrowser *browser)
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
-	g_signal_connect_swapped (G_OBJECT (GET_WIDGET ("close_button")),
+	g_signal_connect_swapped (gtk_dialog_get_widget_for_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_CLOSE),
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
 				  G_OBJECT (data->dialog));
@@ -625,8 +640,5 @@ dlg_personalize_filters (GthBrowser *browser)
 
 	/* run dialog. */
 
-	gtk_window_set_transient_for (GTK_WINDOW (data->dialog),
-				      GTK_WINDOW (browser));
-	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
 	gtk_widget_show (data->dialog);
 }
