@@ -1452,6 +1452,15 @@ gth_image_viewer_class_init (GthImageViewerClass *class)
 			      GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_NONE,
 			      GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_STEP_UP);
 
+	gtk_binding_entry_add_signal (binding_set, GDK_KEY_KP_Page_Down, 0,
+			      "scroll", 2,
+			      GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_NONE,
+			      GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_PAGE_DOWN);
+	gtk_binding_entry_add_signal (binding_set, GDK_KEY_KP_Page_Up, 0,
+			      "scroll", 2,
+			      GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_NONE,
+			      GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_PAGE_UP);
+
 	/* Zoom in */
 
 	gtk_binding_entry_add_signal (binding_set, GDK_KEY_plus, 0,
@@ -1759,10 +1768,10 @@ _set_surface (GthImageViewer  *self,
 	      int              original_height,
 	      gboolean         better_quality)
 {
-	if (self->priv->surface != surface) {
-		_cairo_clear_surface (&self->priv->surface);
-		self->priv->surface = cairo_surface_reference (surface);
-	}
+	if (surface != NULL)
+		cairo_surface_reference (surface);
+	cairo_surface_destroy (self->priv->surface);
+	self->priv->surface = surface;
 
 	_cairo_clear_surface (&self->priv->iter_surface);
 	_g_clear_object (&self->priv->animation);
@@ -1835,10 +1844,9 @@ gth_image_viewer_set_image (GthImageViewer *self,
 			    int             original_width,
 			    int             original_height)
 {
-	if (self->priv->image != image)
-		_g_clear_object (&self->priv->image);
-
-	self->priv->image = g_object_ref (image);
+	_g_object_ref (image);
+	_g_object_unref (self->priv->image);
+	self->priv->image = image;
 
 	if (gth_image_get_is_animation (image)) {
 		GdkPixbufAnimation *animation;
