@@ -25,8 +25,8 @@
 
 
 enum {
-    FILE_LOADED,
-    LAST_SIGNAL
+	FILE_LOADED,
+	LAST_SIGNAL
 };
 
 static guint gth_viewer_page_signals[LAST_SIGNAL] = { 0 };
@@ -110,6 +110,13 @@ void
 gth_viewer_page_focus (GthViewerPage  *self)
 {
 	GTH_VIEWER_PAGE_GET_INTERFACE (self)->focus (self);
+
+}
+
+gboolean
+gth_viewer_page_has_focus (GthViewerPage  *self)
+{
+	return GTH_VIEWER_PAGE_GET_INTERFACE (self)->has_focus (self);
 }
 
 
@@ -220,3 +227,20 @@ gth_viewer_page_get_shortcut_context (GthViewerPage  *self)
 	else
 		return NULL;
 }
+
+
+gboolean
+gth_viewer_page_can_open_clipboard  (GthViewerPage *self,
+				     GdkAtom       *atoms,
+				     int            n_atoms)
+{
+	return GTH_VIEWER_PAGE_GET_INTERFACE (self)->can_open_clipboard (self, atoms, n_atoms);
+}
+
+
+void
+gth_viewer_page_open_clipboard (GthViewerPage *self,
+				GtkClipboard  *clipboard)
+{
+	GTH_VIEWER_PAGE_GET_INTERFACE (self)->open_clipboard (self, clipboard);
+}
